# nucosCR 
a convenient cryptography tools provider in python, works as a working toolbox for pycrypto
This module is in alpha stage, any usage is on your own responsibility.

# Install
pip install nucosCR

# Documentation
[https://pythonhosted.org/nucosCR](https://pythonhosted.org/nucosCR)

# Recommended test runner
nose2 --plugin nose2.plugins.junitxml --junit-xml
